remove

package
v2.1.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 22, 2026 License: Apache-2.0 Imports: 2 Imported by: 0

Documentation

Overview

Package remove provides configuration options for removing container images.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Opt

type Opt func(*Options) error

Opt is a configuration option to remove a container image using github.com/thediveo/morbyd/v2.Session.Run. Please see also Options for more information.

func WithForce

func WithForce() Opt

WithForce forces image removal.

func WithPlatform

func WithPlatform(platform string) Opt

WithPlatform configures to remove an image only for the specified platform(s) variants; WithPlatform can be used multiple times, adding more platforms variants as necessary.

func WithPruneChildren

func WithPruneChildren() Opt

WithPruneChildren configures removing untagged parent images. Yes, that's what the docker image rm docs say.

func WithSchwartz

func WithSchwartz() Opt

WithSchwartz forces The Force; see also WithForce.

type Options

type Options struct {
	client.ImageRemoveOptions
}

Options represents the configuration options when removing a container image.

Jump to